import {
  UserCtor,
  UserInfo,
  UserInfoWithPassword,
  UserWithPasswordCtor,
} from '@core';
import { createHash } from 'crypto';
import { Entity } from './entity';

export class User extends Entity implements UserInfo {
  name: string;

  constructor(raw: UserCtor) {
    super(raw);

    this.name = raw.name ? raw.name : '';
  }

  Info(): UserInfo {
    return {
      uuid: this.uuid,
      name: this.name,
    };
  }
}

export class UserWithPassword extends User implements UserInfoWithPassword {
  password: string;

  constructor(raw: UserWithPasswordCtor) {
    super(raw);

    this.password = createHash('sha256')
      .update(`${this.uuid}+${raw.password}`)
      .digest('hex');
  }

  Info(): UserInfoWithPassword {
    return {
      uuid: this.uuid,
      name: this.name,
      password: this.password,
    };
  }
}
